@@ -11,10 +11,6 @@ import os
 import xlsxwriter
 from copy import deepcopy
 
-try:
-    from pandas import DataFrame
-except ImportError:
-    logging.info("pandas library is required for exporting tables to DataFrame objects")
 
 from typing import List, Dict
 
@@ -23,6 +19,7 @@ from textractor.entities.bbox import BoundingBox
 from textractor.entities.table_cell import TableCell
 from textractor.visualizers.entitylist import EntityList
 from textractor.entities.document_entity import DocumentEntity
+from textractor.entities.selection_element import SelectionElement
 from textractor.utils.geometry_util import get_indices
 from textractor.data.constants import SimilarityMetric, TextTypes, CellTypes
 from textractor.data.constants import (
@@ -92,6 +89,13 @@ class Table(DocumentEntity):
 
         return self._page_id
 
+    @property
+    def checkboxes(self) -> List[SelectionElement]:
+        checkboxes = []
+        for cell in self.table_cells:
+            checkboxes.extend(cell.checkboxes)
+        return checkboxes
+
     @page_id.setter
     def page_id(self, page_id: str):
         """
@@ -242,7 +246,6 @@ class Table(DocumentEntity):
         if cell_property == "":
             logging.info("No cells of this type exist.")
             return []
-        table_cells_by_id = {cell.id: cell for cell in self.table_cells}
         filtered_cells = {}
 
         for cell in self.table_cells:
@@ -389,18 +392,44 @@ class Table(DocumentEntity):
         return new_table
 
 
-    def to_pandas(self):
-        """Converts the table to a pandas DataFrame
-
-        :return: DataFrame for the table
-        :rtype: DataFrame
+    def to_pandas(self, use_columns=False, checkbox_string="X "):
         """
+        Converts the table to a pandas DataFrame
+
+        :param use_columns: If the first row of the table is made of column headers, use them for the pandas dataframe. Only supports single row header.
+        :param checkbox_string: first character is selected checkbox second character is non-selected checkbox
+        :return:
+        """
+        try:
+            from pandas import DataFrame
+        except ImportError:
+            logging.info("pandas library is required for exporting tables to DataFrame objects")
+            return None
+
+        assert len(checkbox_string) == 2, "Checkbox string needs to be exactly two characters"
+
+
+        if use_columns:
+            # Try to automatically get the columns if they are in the first row
+            columns = []
+            for j in range(1, self.column_count + 1):
+                for cell in self.table_cells:
+                    if cell.col_index == j and cell.row_index == 1:
+                        if cell.is_column_header:
+                            columns.append(cell.text)
+            if len(columns) == self.column_count:
+                use_columns = True
+            else:
+                use_columns = False
+                print(f"The number of column header cell do not match the column count, ignoring them, {len(columns)} vs {self.column_count}")
 
         table = [["" for _ in range(self.column_count)] for _ in range(self.row_count)]
-        for cell in self.table_cells:
-            table[cell.row_index - 1][cell.col_index - 1] = cell.text
 
-        return DataFrame(table)
+        for cell in self.table_cells:
+            table[cell.row_index - 1][cell.col_index - 1] = " ".join([checkbox_string[0 if c.is_selected() else 1] for c in cell.checkboxes])  + " ".join([w.text for w in cell.words])
+
+
+        return DataFrame(table[1:] if use_columns else table, columns=columns if use_columns else None)
 
     def to_csv(self) -> str:
         """Returns the table in the Comma-Separated-Value (CSV) format
